@@ -391,6 +391,7 @@ int	l=strlen(env);
 		for (i=0; i<ldapauth_size; i++)
 			if (ldapauth[i] == '\n')
 				ldapauth[i]=0;
+		fclose(f);
 	}
 
 	for (i=0; i<ldapauth_size; )
@@ -1179,11 +1180,10 @@ static int auth_ldap_do2(const char *service,
 
 	if ((cnt=ldap_count_entries(my_ldap_fp, result)) != 1)
 	{
-		free(srch);
-
 		if (cnt)
 			err("emailmap: %d entries returned from search %s (but we need exactly 1)",
 			       cnt, srch);
+		free(srch);
 		ldap_msgfree(result);
 		return -1;
 	}
@@ -2035,6 +2035,7 @@ void auth_ldap_enumerate( void(*cb_func)(const char *name,
 
 				if (!options)
 				{
+					l_value_free(names);
 					perror("CRIT: auth_ldap_enumerate: malloc failed");
 					return;
 				}
