@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 1999 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2007 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
@@ -13,7 +13,7 @@
 #include	"md5/md5.h"
 #include	"auth.h"
 
-static const char rcsid[]="$Id: checkpasswordmd5.c,v 1.7 2004/10/21 00:10:49 mrsam Exp $";
+static const char rcsid[]="$Id: checkpasswordmd5.c,v 1.8 2007/10/07 02:50:45 mrsam Exp $";
 
 int authcheckpasswordmd5(const char *password, const char *encrypted_password)
 {
@@ -27,5 +27,10 @@ int authcheckpasswordmd5(const char *password, const char *encrypted_password)
 	{
                return (strcmp(encrypted_password+5, md5_hash_courier(password)));
 	}
+	if (strncasecmp(encrypted_password, "{MD5RAW}", 8) == 0)
+	{
+		return (strcmp(encrypted_password+8, md5_hash_raw(password)));
+	}
+
 	return (-1);
 }
